@@ -19,12 +19,22 @@ class AsyncTests: XCTestCase {
     func testSwiftCallsRustAsyncFn() async throws {
         await rust_async_return_null()
     }
-    
-    func testSwiftCallsRustAsyncFnRetU8() async throws {
-        let num = await rust_async_return_u8()
+   
+    /// Verify that we can call async Rust functions
+    func testSwiftCallsRustAsyncFnReflectU8() async throws {
+        let num = await rust_async_reflect_u8(123)
         XCTAssertEqual(num, 123)
     }
     
+    /// Verify that we can call async Rust methods
+    func testSwiftCallsRustAsyncMethodReflectU16() async throws {
+        let test = TestRustAsyncSelf()
+
+        let num = await test.reflect_u16(567)
+        XCTAssertEqual(num, 567)
+    }
+
+    
     func testSwiftCallsRustAsyncFnRetStruct() async throws {
         let _: AsyncRustFnReturnStruct = await rust_async_return_struct()
     }
